@@ -1,4 +1,22 @@
 from django.db import migrations, transaction
+from django.db.models.signals import post_delete
+from django.dispatch import receiver
+from django.utils.timezone import now
+
+from paper_uploads.models import CollectionItemBase
+
+
+@receiver(post_delete, sender=CollectionItemBase)
+def on_delete_collection_item(sender, instance, **kwargs):
+    """
+    Обновление поля `modified_at` коллекции при удалении элемента,
+    чтобы метод `get_last_modified()` возвращал корректные данные.
+    """
+    if instance.collection_id and instance.collection_content_type_id:
+        collection_cls = instance.get_collection_class()
+        collection_cls.objects.filter(pk=instance.collection_id).update(
+            modified_at=now()
+        )
 
 
 class RenameFileField(migrations.RunPython):
@@ -20,7 +38,7 @@ class RenameFileField(migrations.RunPython):
 
             if isinstance(field, FileResourceFieldBase):
                 with transaction.atomic(using=db):
-                    field.related_model.objects.db_manager(db).filter(
+                    field.related_model._base_manager.db_manager(db).filter(
                         owner_app_label=self.app_label,
                         owner_model_name=self.model_name,
                         owner_fieldname=old_name,
@@ -50,7 +68,7 @@ class RenameFileModel(migrations.RunPython):
         for field in state_model._meta.fields:
             if isinstance(field, FileResourceFieldBase):
                 with transaction.atomic(using=db):
-                    field.related_model.objects.db_manager(db).filter(
+                    field.related_model._base_manager.db_manager(db).filter(
                         owner_app_label=self.app_label,
                         owner_model_name=old_name,
                         owner_fieldname=field.name,
